/*********************************************************/
/* This source code copyright (c) 1991-2001, Aaron Giles */
/* See the Read Me file for licensing information.       */
/* Contact email: mac@aarongiles.com                     */
/*********************************************************/

#ifndef __SENDAPPLEEVENTS__
#define __SENDAPPLEEVENTS__

extern OSErr SendSetWindowBounds(WindowPtr theWindow, Rect *theRect);
extern OSErr SendSetZoomed(WindowPtr theWindow, Boolean zoomed);
extern OSErr SendNewPalette(ImageHandle theImage, DescType thePalette);
extern OSErr SendDither(ImageHandle theImage, Boolean dither);
extern OSErr SendQuality(ImageHandle theImage, DescType theQuality);
extern OSErr SendSetSelection(ImageHandle theImage, Rect *theRect);
extern OSErr SendCloneDocument(ImageHandle theImage, ImageHandle *theNewImage);
extern OSErr SendSetImageBounds(WindowPtr theWindow, Rect *theRect);
extern OSErr SendSetWindowVis(WindowPtr theWindow, Boolean visible);
extern OSErr SendOpenDocument(FSSpec *theSpec);
extern OSErr SendCreateWindow(DescType windowID);
extern OSErr SendCloseWindow(WindowPtr theWindow);
extern OSErr SendSaveDocument(FSSpec *theSpec, OSType theFormat, Boolean preview,
			Boolean palette, Boolean icons, short cropWhat);
extern OSErr SendSlideShow(void);
extern OSErr SendPrintDocument(ImageHandle theImage);
extern OSErr SendQuitApplication(void);
extern OSErr SendSetFullScreen(WindowPtr theWindow, Boolean full);
extern OSErr SendSetDrawBounds(WindowPtr theWindow, Rect *theRect);
extern OSErr SendMoveToFront(WindowPtr theWindow);
extern OSErr SendCopy(void);

#endif
